.. currentmodule:: abjad.tools.pitchtools

set_written_pitch_of_pitched_components_in_expr
===============================================

.. autofunction:: set_written_pitch_of_pitched_components_in_expr
